csep.core.poisson\_evaluations.conditional\_likelihood\_test
============================================================

.. currentmodule:: csep.core.poisson_evaluations

.. autofunction:: conditional_likelihood_test